@@ -100,12 +100,41 @@ class FlareLightCurve(lk.LightCurve):
             return trend_folded_flux[folded_lc.time_original.argsort()] - 1
         return 0
 
+    def _mask_eclipse(self):
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore", category=AstropyUserWarning)
+
+            sigma = mad_std(self.flux, ignore_nan=True)
+            eclipse_mask = self.flux < np.nanmedian(self.flux) - 3 * sigma
+            if hasattr(self.flux, "mask"):
+                eclipse_mask = np.logical_xor(eclipse_mask, self.flux.mask)
+
+            i_start_array, i_stop_array = find_consecutive(
+                np.nonzero(eclipse_mask)[0], 3, gap=1.2 * self.meta["TIMEDEL"], data=self.time.value
+            )
+
+            lc = self.copy()
+            if i_start_array is not None:
+                if i_start_array.size > 3 and lc.time.value[i_start_array[0]] < lc.time.value[i_stop_array[-1]] - 10:
+                    for i in range(i_start_array.size):
+                        t_start = self.time.value[i_start_array[i]]
+                        t_stop = self.time.value[i_stop_array[i]]
+                        duration = t_stop - t_start
+                        t_start_ext, t_stop_ext = extend(
+                            lc.time.value, (lc.flux - 1) / sigma, t_start, t_stop, duration, n_sigma=0, mode=-1
+                        )
+                        lc.flux[(self.time.value >= t_start_ext) & (self.time.value <= t_stop_ext)] = np.nan
+
+            self.meta["eclipse_mask"] = np.isnan(lc.flux)
+
+        return lc
+
     def _extend_multiple_events(self, i_start_array, i_stop_array, max_extend_indexes=45):
         i_start_ext_array = np.zeros_like(i_start_array)
         i_stop_ext_array = np.zeros_like(i_stop_array)
 
         lc = self.copy()
-        lc.flux[self.clip_mask] = np.nan
+        lc.flux[self.eclipse_mask] = np.nan
         lc = lc.remove_nans()
 
         for i in range(i_start_array.size):
@@ -133,13 +162,10 @@ class FlareLightCurve(lk.LightCurve):
 
     def _standardize(self):
         flux_series = pd.Series(self.detrended_flux.value, index=pd.DatetimeIndex(self.time.datetime))
+
         rolling_window = flux_series.rolling(pd.Timedelta(2, unit="d"), center=True)
         rolling_std = rolling_window.apply(mad_std, kwargs={"ignore_nan": True})
-
-        nan_mask = np.isnan(self.detrended_flux.value)
-        rolling_std[nan_mask] = np.nan
-        global_std = mad_std(self.detrended_flux.value, ignore_nan=True) * 2.5 / 3
-        rolling_std[rolling_std < global_std] = global_std
+        rolling_std[np.isnan(self.detrended_flux.value)] = np.nan
 
         standardized_flux = (self.detrended_flux.value - 1) / rolling_std
 
@@ -222,44 +248,20 @@ class FlareLightCurve(lk.LightCurve):
 
         self._query_object_type_from_simbad()
 
-        with warnings.catch_warnings():
-            warnings.simplefilter("ignore", category=AstropyUserWarning)
-
-            sigma = mad_std(self.flux, ignore_nan=True)
-            clip_mask = self.flux < np.nanmedian(self.flux) - 3 * sigma
-            if hasattr(self.flux, "mask"):
-                clip_mask = np.logical_xor(clip_mask, self.flux.mask)
-
-            i_start_array, i_stop_array = find_consecutive(
-                np.nonzero(clip_mask)[0], 3, gap=1.2 * self.meta["TIMEDEL"], data=self.time.value
-            )
-
-            lc = self.copy()
-            if i_start_array is not None:
-                if i_start_array.size > 3 and lc.time.value[i_start_array[0]] < lc.time.value[i_stop_array[-1]] - 10:
-                    for i in range(i_start_array.size):
-                        t_start = self.time.value[i_start_array[i]]
-                        t_stop = self.time.value[i_stop_array[i]]
-                        duration = t_stop - t_start
-                        t_start_ext, t_stop_ext = extend(
-                            lc.time.value, (lc.flux - 1) / sigma, t_start, t_stop, duration, n_sigma=0, mode=-1
-                        )
-                        lc.flux[(self.time.value >= t_start_ext) & (self.time.value <= t_stop_ext)] = np.nan
-
-            self.meta["clip_mask"] = np.isnan(lc.flux)
-            model_flux = self._generate_model()
-            detrended_flux, trend_flux = flatten(
-                self.time.value,
-                lc.flux - model_flux,
-                method="biweight",
-                window_length=window_length,
-                return_trend=True,
-            )
-            trend_flux += model_flux
-            self.add_columns(
-                [detrended_flux * self.flux.unit, trend_flux * self.flux.unit], names=["detrended_flux", "trend_flux"]
-            )
-            self._standardize()
+        masked_lc = self._mask_eclipse()
+        model_flux = self._generate_model()
+        detrended_flux, trend_flux = flatten(
+            self.time.value,
+            masked_lc.flux - model_flux,
+            method="biweight",
+            window_length=window_length,
+            return_trend=True,
+        )
+        trend_flux += model_flux
+        self.add_columns(
+            [detrended_flux * self.flux.unit, trend_flux * self.flux.unit], names=["detrended_flux", "trend_flux"]
+        )
+        self._standardize()
 
     def find_candidates(self, n_sigma: float = 3, n_consecutive: int = 2):
         """Find the candidates of flares."""
@@ -320,7 +322,7 @@ class FlareLightCurve(lk.LightCurve):
                     time, flux = fill_gaps(time, flux, lc_candidate.cadenceno)
 
                 if flux.size >= 4:
-                    proba_array[row.Index] = round(get_flare_probability(time, flux), 2)
+                    proba_array[row.Index] = round(get_flare_probability(time, flux), 3)
                 snr_array[row.Index] = round(np.max(flux), 2)
 
             self.candidates.flare_prob = proba_array
@@ -342,7 +344,7 @@ class FlareLightCurve(lk.LightCurve):
                     n_row += 1
 
                 self.candidates.amp = np.round(amp, 3)
-                self.candidates.dur = np.round(dur, 0).astype(int)
+                self.candidates.dur = np.round(dur, 1)
                 self.candidates.ed = np.round(ed, 2)
 
     def find_flares(self):
@@ -373,7 +375,7 @@ class FlareLightCurve(lk.LightCurve):
             self.candidates.loc[self.candidates.sso, "flare_prob"] = -999
             cond_list = [self.candidates.flare_prob >= threshold, self.candidates.flare_prob == -999]
             candidate_type_array = np.select(cond_list, ["flare", "sso"], "non-flare")
-            color_array = np.select(cond_list, ["tab:red", "tab:brown"], "tab:gray")
+            color_array = np.select(cond_list, ["tab:red", "tab:orange"], "tab:gray")
             with plt.style.context(lk.MPLSTYLE):
                 for row in self.candidates.itertuples():
                     candidate_type = candidate_type_array[row.Index]
@@ -438,8 +440,8 @@ class FlareLightCurve(lk.LightCurve):
                             f"flare prob: {row.flare_prob}\n"
                             f"snr: {row.snr}\n"
                             f"amp: {row.amp}\n"
-                            f"dur: {row.dur}\n"
-                            f"ed: {row.ed}"
+                            f"dur: {row.dur}\n m"
+                            f"ed: {row.ed} s"
                         )
                     at = AnchoredText(box_str, loc="upper right", frameon=True, prop={"multialignment": "right"})
                     at.patch.set_boxstyle("round,pad=0.,rounding_size=0.2")
