@@ -30,13 +30,13 @@ CANDIDATES_COLUMNS = [
 FC_PARAMETERS = {
     "abs_energy": None,
     "first_location_of_maximum": None,
+    "index_mass_quantile": [{"q": 0.5}],
     "kurtosis": None,
     "length": None,
     "maximum": None,
     "root_mean_square": None,
     "skewness": None,
     "standard_deviation": None,
-    "time_reversal_asymmetry_statistic": [{"lag": 2}],
 }
 
 
